/*
 * Copyright (C) 2024, KylinSoft Co., Ltd.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * Authors: hxf <hewenfei@kylinos.cn>
 *
 */

#include <QGuiApplication>
#include <QApplication>
#include <QQuickView>
#include <QList>

#include "widget.h"
#include "widget-loader.h"
#include "widget-item.h"
#include "config-loader.h"
#include "widget-container.h"

int main(int argc, char *argv[])
{
    QApplication app(argc, argv);

    QStringList widgets;
//    widgets << "org.ukui.panel.taskmanager";
//    widgets << "org.ukui.panel.test";
    widgets << "org.ukui.menu.starter";
//    widgets << "org.ukui.panel.widget.test";
    widgets << "org.ukui.panel.taskManager";
    auto view = new QQuickView;
    view->setResizeMode(QQuickView::SizeRootObjectToView);
    view->resize(600, 600);
    view->setColor(QColor(Qt::transparent));
    view->setSource(QUrl("qrc:///main.qml"));

    UkuiQuick::WidgetContainer container("ukui-panel", "panel-0");
    QList<UkuiQuick::Widget *> widgetList;
    UkuiQuick::WidgetLoader loader;
    for (const auto &id : widgets) {
        UkuiQuick::Widget *widget = loader.loadWidget(id);
        if (!widget) {
            continue;
        }
        container.addWidget(widget);
        widgetList << widget;

        UkuiQuick::WidgetItem *widgetItem = UkuiQuick::WidgetItem::itemForWidget(widget);
        if (!widgetItem) {
            continue;
        }

        widgetItem->setParentItem(view->rootObject());
    }

    for (const auto &widget : widgetList) {
        qDebug() << "Widget main url:" << widget->content().fileUrl(UkuiQuick::WidgetContent::Main);
        qDebug() << "Widget id:" << widget->id() << "; Has error:" << widget->hasUiError() << widget->uiError() << "\n";
    }

    view->show();

    return QGuiApplication::exec();
}
